@@ -5,11 +5,11 @@ colVars <- function(x, suma = NULL, std = FALSE) {
   if ( !is.null(suma) ) {
     m <- suma
   } else {
-    m <- colsums(x)
+    m <- as.vector(colsums(x))
   }
 
   n <- nrow(x)
-  x2 <- colsums(x^2)
+  x2 <- as.vector(colsums(x^2))
   s <- ( x2 - m^2/n ) / (n - 1)
 
   if ( std == TRUE )  s <- sqrt(s)
