@@ -2,6 +2,6 @@ cova <- function(x) {
   ## x must be a matrix
   n <- nrow(x)  ## sample size
   mat <- t( x )
-  mat <- mat - rowMeans(mat)
+  mat <- mat - as.vector(rowmeans(mat))
   tcrossprod( mat ) / (n - 1)
 }
\ No newline at end of file
