@@ -26,5 +26,6 @@ unsigned int generatekey2(const string & ,unsigned  int );
 static const size_t InitialFNV = 2166136261U;
 static const size_t FNVMultiple = 16777619;
 size_t generatekey1(const string &);
-
+double digamma(double);
+double trigamma(double);
 #endif
